const scatterPlot = () => {
  plotConfig = getScatterPlotConfig();
  
  const width = +plotConfig.width;
  const height = +plotConfig.height;
  const margin = plotConfig.margin;
  const xAxisLabelOffset = +plotConfig.xAxisLabelOffset;
  const yAxisLabelOffset = +plotConfig.yAxisLabelOffset;
  const yAxisTextOffset = +plotConfig.yAxisTextOffset;
  const innerHeight = +plotConfig.innerHeight;
  const innerWidth = +plotConfig.innerWidth;
  const horizontalTicks = +plotConfig.horizontalTicks;
  const circleRadiusMin = +plotConfig.circleRadiusMin;
  const circleRadiusMax = +plotConfig.circleRadiusMax;
  
  const svg = d3.select('#scatter-plot-container');
  svg.attr('height', height).attr('width', width);

  const body = d3.select('#scatter-plot-body');
  body.attr('transform', 'translate(' + margin.left + ',' + margin.top + ')');

  showTitle(svg,"Logan Airport Weather vs Delay");

  showLabel(body,plotConfig);

  const leftScale = d3
    .scaleLinear()
    .domain(d3.extent(data, d => d.TMAX))
    .range([innerHeight, 0]);

  const xScale = d3
    .scaleTime()
    .domain(d3.extent(data, d => d.date))
    .range([0, innerWidth]);

  const sizeScale = d3
    .scaleLinear()
    .domain(d3.extent(data, d => d.DEP_DELAY))
    .range([circleRadiusMin, circleRadiusMax]);

  const xAxis = d3
    .axisBottom(xScale)
    .tickFormat(d3.timeFormat('%b'))
    .tickSize(-innerHeight);

  const leftAxis = d3
    .axisLeft(leftScale)
    .tickSize(-innerWidth)
    .ticks(horizontalTicks);

  body
    .append('g')
    .call(leftAxis)
    .selectAll('.domain')
    .remove();
  d3.selectAll('.tick')
    .select('text')
    .attr('transform', 'translate(' + -yAxisTextOffset + ',0)')
    .attr('dy', '.32em');

  body
    .append('g')
    .attr('transform', 'translate(0,' + innerHeight + ')')
    .call(xAxis)
    .selectAll('.domain')
    .remove();

  let cScale = d3
    .scaleLinear()
    .domain(d3.extent(data, d => d.PRCP))
    .range([0, 1]);

  let colorMap = d3.interpolateRgb(d3.rgb('#55ffff'), d3.rgb('#3399ff'));

  let weatherContainer = body.append('g').attr('id', 'weather-data');
  weatherContainer
    .selectAll('.dot')
    .data(data)
    .enter()
    .append('circle')
    .attr('r', d => sizeScale(d.DEP_DELAY))
    .attr('cx', d => xScale(d.date))
    .attr('cy', d => leftScale(d.TMAX))
    .attr('fill', d => {
      return d.PRCP < 0.1 ? 'rgba(224,224,240,0.5)' : colorMap(cScale(d.PRCP));
    })
    .append('title')
    .text(d => d.DEP_DELAY);
};